//
//  BuscarISBNController.swift
//  trotalibros
//
//  Created by EDU on 13/11/16.
//  Copyright © 2016 EDU. All rights reserved.
//  Clase que busca un isbn de un  libro en la base de datos de isbndb.com y en la base de datos propia

import Foundation
import UIKit


class BuscarISBNController: UIViewController,  UITextFieldDelegate {
    
     //variables conectadas con los elementos de la pantalla
    @IBOutlet weak var ISBNField: UITextField!
    
    //variables internas
    var titulo: NSString = " "
    var isbn: NSString = " "
    var idioma: NSString = " "
    var editorial: NSString = " "
    var sinopis: NSString = " "
    var autor: NSString = " "
    var id_libro: Int = 0

    
    //Función que busca un isbn en la base de datos
    @IBAction func buscarISBN(_ sender: AnyObject) {
        
        if (ISBNField.text!.isEmpty){
            SCLAlertView().showWarning("ATENCIÓN", subTitle: "Todos los campos son obligatorios",closeButtonTitle:"OK")
        }
            
        else{
            
            var post:NSString = "ISBN=\(ISBNField.text!)" as NSString
            
            var ruta = Utils.agafaRuta(string: "existe_libro.php")
            let url:NSURL = NSURL(string: ruta as String)!
            
            let postData:NSData = post.data(using: String.Encoding.utf8.rawValue)! as NSData
            
            let postLength:NSString = String( postData.length ) as NSString
            
            let request:NSMutableURLRequest = NSMutableURLRequest(url: (url as NSURL) as URL)
            request.httpMethod = "POST"
            request.httpBody = postData as Data
            request.setValue(postLength as String, forHTTPHeaderField: "Content-Length")
            request.setValue("application/x-www-form-urlencoded", forHTTPHeaderField: "Content-Type")
            request.setValue("application/json", forHTTPHeaderField: "Accept")
            
            var reponseError: NSError?
            var response: URLResponse?
            
            var urlData: NSData?
            do {
                urlData = try NSURLConnection.sendSynchronousRequest(request as URLRequest, returning:&response) as NSData?
            } catch var error as NSError {
                reponseError = error
                urlData = nil
            }
            
            if ( urlData != nil ) {
                let res = response as! HTTPURLResponse!;
                
                if ((res?.statusCode)! >= 200 && (res?.statusCode)! < 300)
                {
                    var responseData:NSString  = NSString(data:urlData! as Data, encoding:String.Encoding.utf8.rawValue)!
                    
                    var error: NSError?
                    
                    let jsonData:NSDictionary = (try! JSONSerialization.jsonObject(with: urlData! as Data, options:JSONSerialization.ReadingOptions.mutableContainers )) as! NSDictionary
                    
                    let success:NSInteger = jsonData.value(forKey: "success") as! NSInteger
                    
                    //Si existe vamos a la ficha del libro
                    if(success == 1)
                    {
                        id_libro = jsonData.value(forKey: "id_libro") as! NSInteger
                         self.performSegue(withIdentifier: "goToLibro2", sender: self)
                    }
                    else{
                        // Si no exite pedimos información a isbndb.com
                        if(success == 2){
                          pedirSBN(isbn: ISBNField.text!)
                        }
                        else{
                            var error_msg:NSString
                            
                            if jsonData["error_message"] as? NSString != nil {
                                error_msg = jsonData["error_message"] as! NSString
                            } else {
                                error_msg = "Unknown Error"
                            }
                            SCLAlertView().showError("Error", subTitle:error_msg as String, closeButtonTitle:"Cerrar")
                        }
                    }
                    
                } else {
                    SCLAlertView().showError("Error", subTitle:"La connexión falló", closeButtonTitle:"Cerrar")
                    
                }
            } else {
                SCLAlertView().showError("Error", subTitle:"La connexión falló", closeButtonTitle:"Cerrar")
                
            }
            
        }
    }
    
    //Busca un libro en la base de datos de isbndb.com y devuelve la información
    func pedirSBN(isbn: String) {
        
        if (isbn.isEmpty){
            SCLAlertView().showWarning("ATENCIÓN", subTitle: "Todos los campos son obligatorios",closeButtonTitle:"OK")
        }
            
        else{
            var ruta = Utils.agafaRutaISBN(string: isbn)
            let url:NSURL = NSURL(string: ruta as String)!
            
            let request:NSMutableURLRequest = NSMutableURLRequest(url: (url as NSURL) as URL)
            request.httpMethod = "GET"
            request.setValue("application/x-www-form-urlencoded", forHTTPHeaderField: "Content-Type")
            
            
            var reponseError: NSError?
            var response: URLResponse?
            
            var urlData: NSData?
            do {
                urlData = try NSURLConnection.sendSynchronousRequest(request as URLRequest, returning:&response) as NSData?
            } catch var error as NSError {
                reponseError = error
                urlData = nil
            }
            
            if ( urlData != nil ) {
                let res = response as! HTTPURLResponse!;
                
                if ((res?.statusCode)! >= 200 && (res?.statusCode)! < 300)
                {
                    
                    var error: NSError?
                    
                    let json = JSON(data: urlData! as Data)
                    
                    //guardamos la información en variables una vez descodificadas
                    
                    titulo = json["data"][0]["title"].stringValue as NSString
                    idioma = json["data"][0]["language"].stringValue as NSString;
                    editorial = json["data"][0]["publisher_name"].stringValue as NSString;
                    sinopis = json["data"][0]["summary"].stringValue as NSString;
                    autor = json["data"][0]["author_data"][0]["name"].stringValue as NSString;
                    
                    self.performSegue(withIdentifier: "goToFormulari", sender: self)
                    
                    
                } else {
                    SCLAlertView().showError("Error", subTitle:"La connexión falló", closeButtonTitle:"Cerrar")
                    
                }
            } else {
                SCLAlertView().showError("Error", subTitle:"La connexión falló", closeButtonTitle:"Cerrar")
                
            }
            
        }
    }
    
     //Se preparan los parámetros para cambiar de pantalla
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "goToFormulari" {
           let vc = segue.destination as! NuevoLibroController
            vc.titulo=titulo
            vc.autor=autor
            vc.isbn=ISBNField.text! as NSString
        }
        else{
            if segue.identifier == "goToLibro2" {
                let vc = segue.destination as! LibroController
                vc.id_libro=id_libro
            }
        }
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
    }
    
    //Escodenmos el teclado
    func textFieldShouldReturn(textField: UITextField) -> Bool {
        ISBNField.resignFirstResponder()
        return true;
    }
    
    //Escodenmos el teclado al tocar el fondo de pantalla
    override func touchesBegan(_ touches: Set<UITouch>, with event: UIEvent?) {
        ISBNField.resignFirstResponder()
        self.view.endEditing(true)
    }
}
