//
//  LIbrosTrotadosController.swift
//  trotalibros
//
//  Created by EDU on 30/11/16.
//  Copyright © 2016 EDU. All rights reserved.
//  Clase que muestra los libros trotados en formato tabla

import Foundation
import UIKit
import QuartzCore

class LIbrosTrotadosController: UITableViewController {
    
    //variables internas
    var titulos: [String] = []
    var id_libros: [Int] = []
    var isbns: [String] = []
    var portadas: [String] = []
    var autores: [String] = []
    var generos: [String] = []
    var observaciones: [String] = []
    
    
    //Se obtiene los libros trotados del usuario y se guardan en una array
    func obtenerDatos(){
        let prefs:UserDefaults = UserDefaults.standard
        var id_usuario=prefs.string(forKey: "IDUSUARIO")! as String
        
        var post:NSString = "id_usuario=\(id_usuario)" as NSString
        
        var ruta = Utils.agafaRuta(string: "libros_trotados_usuario.php")
        let url:NSURL = NSURL(string: ruta as String)!
        
        let postData:NSData = post.data(using: String.Encoding.ascii.rawValue)! as NSData
        
        let postLength:NSString = String( postData.length ) as NSString
        
        let request:NSMutableURLRequest = NSMutableURLRequest(url: (url as NSURL) as URL)
        request.httpMethod = "POST"
        request.httpBody = postData as Data
        request.setValue(postLength as String, forHTTPHeaderField: "Content-Length")
        request.setValue("application/x-www-form-urlencoded", forHTTPHeaderField: "Content-Type")
        request.setValue("application/json", forHTTPHeaderField: "Accept")
        
        
        var reponseError: NSError?
        var response: URLResponse?
        
        var urlData: NSData?
        do {
            urlData = try NSURLConnection.sendSynchronousRequest(request as URLRequest, returning:&response) as NSData?
        } catch var error as NSError {
            reponseError = error
            urlData = nil
        }
        
        if ( urlData != nil ) {
            let res = response as! HTTPURLResponse!;
            
            var responseData:NSString  = NSString(data:urlData! as Data, encoding:String.Encoding.utf8.rawValue)!
            
            NSLog("Response ==> %@", responseData);
            
            if ((res?.statusCode)! >= 200 && (res?.statusCode)! < 300)
            {
                let json = JSON(data: urlData! as Data)
                
                if(json.count>0){
                    for index in 0...(json.count-1)
                    {
                        //guardamos cada libro en arrays, cada una para un parámetro
                        titulos.append((json[index]["titulo"].stringValue as NSString) as String)
                        id_libros.append(json[index]["id_libro"].intValue as Int)
                        isbns.append((json[index]["isbn"].stringValue as NSString) as String)
                        portadas.append((json[index]["portada"].stringValue as NSString) as String)
                        generos.append((json[index]["genero"].stringValue as NSString) as String)
                        autores.append((json[index]["autor"].stringValue as NSString) as String)
                        observaciones.append((json[index]["observacio"].stringValue as NSString) as String)
                    }
                }
                //cargamos la tabla de la vista
                self.tableView!.reloadData()
                
            }
            else
            {
                SCLAlertView().showError("Error", subTitle:"La connexión falló", closeButtonTitle:"Cerrar")
                
            }
        }
        else
        {
            SCLAlertView().showError("Error", subTitle:"La connexión falló2", closeButtonTitle:"Cerrar")
            
        }
    }
    
    
    
    override func tableView(_ tableView: UITableView?, numberOfRowsInSection section: Int) -> Int
    {
        return self.titulos.count;
    }
    
    //Rellenamos cada fila de la tabla con un libro. cada elemento de la fila tiene un TAG que lo diferencia
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "trotadosCell", for: indexPath)
        
        if let tituloLabel = cell.viewWithTag(100) as? UILabel
        {
            tituloLabel.text = self.titulos[indexPath.row]
        }
        
        if let autorLabel = cell.viewWithTag(102) as? UILabel
        {
            autorLabel.text = self.autores[indexPath.row]
        }
        
        if let generoLabel = cell.viewWithTag(103) as? UILabel
        {
            generoLabel.text = self.generos[indexPath.row]
        }
        
        //Si tiene imagen la mostramos descodificada en base64
        if(self.portadas[indexPath.row] != "-"){
            if let ratingImageView = cell.viewWithTag(101) as? UIImageView {
                let decodedData = NSData(base64Encoded: self.portadas[indexPath.row] as String, options: NSData.Base64DecodingOptions(rawValue: 0))
                ratingImageView.contentMode = UIViewContentMode.scaleToFill
                ratingImageView.image = UIImage(data: decodedData! as Data)
            }
        }
        
        return cell
    }
    
    
    //Ponemos un título a la tabla
    override func tableView(_ tableView: UITableView, titleForHeaderInSection section: Int) -> String?
    {
        return "Ofreces \(self.titulos.count) libros"
    }
    
    //Se prepara los parámetros para cambiar de pantalla
    override func prepare(for segue: UIStoryboardSegue, sender: Any?)
    {
        let index = tableView.indexPathForSelectedRow!
        
        let id_libro = self.id_libros[index.row]
        
        if segue.identifier == "goToLibro7" {
            let vc = segue.destination as! LibroController
            vc.id_libro = id_libro
            vc.flag = 1
        }
    }
    
    override func didReceiveMemoryWarning()
    {
        super.didReceiveMemoryWarning()
    }
    
    
    //Actualizamos cuando volvemos a la pantalla
    override func viewWillAppear(_ animated: Bool)
    {
        super.viewWillAppear(animated)
        actualizar()
    }
    
    
    //Actualizamos libros y eliminamos todo lo anterior para no duplicar
    func actualizar()
    {
        self.tableView .reloadData()
        self.refreshControl?.endRefreshing()
        titulos.removeAll()
        id_libros.removeAll()
        isbns.removeAll()
        portadas.removeAll()
        autores.removeAll()
        generos.removeAll()
        self.obtenerDatos();
    }
    
    
    //Función que se ejecuta al iniciar la pantalla la primera vez
    override func viewDidLoad()
    {
        super.viewDidLoad()
        self.title = "Libros para cambiar"
        obtenerDatos()
        var refreshControl = UIRefreshControl()
        refreshControl.addTarget(self, action: Selector("actualizar"), for: UIControlEvents.valueChanged)
        self.refreshControl = refreshControl
    }
    
}


