//
//  MapaController.swift
//  trotalibros
//
//  Created by Andorsoft on 16/11/16.
//  Copyright © 2016 EDU. All rights reserved.
//  Clase que muestra en el mapa los usuarios cercanos al usuario según el radio seleccionado

import UIKit
import QuartzCore
import MapKit
import CoreLocation

class MapaController: UIViewController,CLLocationManagerDelegate,MKMapViewDelegate{
    
     //variables conectadas con los elementos de la pantalla
    @IBOutlet weak var mapView: MKMapView!
    @IBOutlet weak var kmSlider: UISlider!
    @IBOutlet weak var kmLabel: UILabel!
    
    //variables internas
    var latitudes:[String] = []
    var longitudes:[String] = []
    var nombres:[String] = []
    var idUsuarios:[Int] = []
    var id_usuario = 0
    var nombre_usuario: String = ""
    var locationManager: CLLocationManager!
    var total_usuarios:Int = 0
    var latitud_usuario:Double = 0
    var longitud_usuario:Double = 0
    
    
    //Mostramos en el label el valor del Slider cada vez que se modifica
    @IBAction func kmSeleccion(_ sender: Any) {
        
        var selectedValue = Int(kmSlider.value)
        kmLabel.text = String(stringInterpolationSegment: selectedValue) + " KM"
    }
    
    
    //Recargamos la pantalla con los nuevos datos al pulsar el botón central
    @IBAction func actualizarMapa(_ sender: Any) {
        
        mapView.removeAnnotations(mapView.annotations)
        latitudes.removeAll()
        longitudes.removeAll()
        nombres.removeAll()
        idUsuarios.removeAll()
        obtenerDatos()
        completarMapa()
    }
    
    //Buscamos la localización del usuario
    func completarMapa(){
        
        if (CLLocationManager.locationServicesEnabled())
        {
            locationManager = CLLocationManager()
            locationManager.delegate = self
            locationManager.desiredAccuracy = kCLLocationAccuracyBest
            locationManager.requestAlwaysAuthorization()
            locationManager.startUpdatingLocation()
            mapView.showsUserLocation = true
            mapView.delegate = self
    
        }
        else{
            print("Location service disabled");
        }

    }
    
    // Se define el tipo de anotación en el mapa
    func mapView(_ mapView: MKMapView, viewFor annotation: MKAnnotation) -> MKAnnotationView? {
        if annotation is MKUserLocation
        {
            return nil
        }
        var annotationView = self.mapView.dequeueReusableAnnotationView(withIdentifier: "Pin")
        if annotationView == nil{
            annotationView = AnnotationView(annotation: annotation, reuseIdentifier: "Pin")
            annotationView?.canShowCallout = false
             annotationView?.isEnabled = true
        }else{
            annotationView?.annotation = annotation
        }
      
        annotationView?.image = UIImage(named: "view")
    
        return annotationView
    }
    
    
    //Función que se ejecuta al puslar sobre una anotación en el mapa, si la anotación no es el usuario se cambia de pantalla para mostrar los libros del usuario seleccionado
    func mapView(_ mapView: MKMapView,didSelect view: MKAnnotationView)
    {
        if view.annotation is MKUserLocation
        {
            return
        }

        let customAnnotation = view.annotation as! CustomPointAnnotation
        
        //No es el usuario
        if(customAnnotation.id_usuari>0)
        {
            let views = Bundle.main.loadNibNamed("CustomCalloutView", owner: nil, options: nil)
            let calloutView = views?[0] as! CustomCalloutView
            calloutView.usuariButton.setTitle(customAnnotation.usuari, for: .normal);
            calloutView.usuariButton.addTarget(self, action: #selector(self.pressed), for: .touchUpInside)
            calloutView.usuariButton.isUserInteractionEnabled = true
            id_usuario = customAnnotation.id_usuari
            nombre_usuario = customAnnotation.usuari
        
            //Definimos el comportamiento
            let tapGesture = UITapGestureRecognizer(target: self, action: Selector(("pressed:")))
            calloutView.usuariButton.addGestureRecognizer(tapGesture)
            calloutView.usuariButton.isUserInteractionEnabled = true
       
            calloutView.center = CGPoint(x: view.bounds.size.width / 2, y: -calloutView.bounds.size.height*0.52)
            pressed()
        }
        else
        {
           SCLAlertView().showInfo("", subTitle:"Aquí están mis libros", closeButtonTitle:"Cerrar")
        }
    }
    
    func mapView(_ mapView: MKMapView, didDeselect view: MKAnnotationView) {
        if view.isKind(of: AnnotationView.self)
        {
            for subview in view.subviews
            {
               subview.removeFromSuperview()
            }
        }
    }
    
    
    //Definimos las anotaciones con la información de cada usuario
    func locationManager(_ manager: CLLocationManager,didUpdateLocations locations: [CLLocation]) {
        
        let userLocation:CLLocation = locations[0] as CLLocation
        
        longitud_usuario = userLocation.coordinate.longitude
        latitud_usuario = userLocation.coordinate.latitude
        
   
        //Centramos el mapa según la psoición de los libros
        let coordinations = CLLocationCoordinate2D(latitude:NSString(string: latitudes[0]).doubleValue,longitude: NSString(string: longitudes[0]).doubleValue)
        let span = MKCoordinateSpanMake(0.01,0.01)
        let region = MKCoordinateRegion(center: coordinations, span: span)
        mapView.setRegion(region, animated: true)
        
        
        // Localización de los libros del usuario
        var point = CustomPointAnnotation(coordinate: CLLocationCoordinate2D(latitude: NSString(string: latitudes[0]).doubleValue , longitude: NSString(string: longitudes[0]).doubleValue ))
        point.usuari = "Mis libros"
        point.id_usuari = 0
        self.mapView.addAnnotation(point)
        
        
        //Localización de los usuarios disponibles cerca
        if(total_usuarios>1)
        {
            for index in 1...(total_usuarios-1)
            {
                var point = CustomPointAnnotation(coordinate: CLLocationCoordinate2D(latitude: NSString(string: latitudes[index]).doubleValue , longitude: NSString(string: longitudes[index]).doubleValue ))
                point.usuari = nombres[index]
                point.id_usuari = idUsuarios[index]
                self.mapView.addAnnotation(point)
            }
        }
        
        manager.stopUpdatingLocation()
        
    }
    
    
    //El servior devuelve la información de los usuarios cercanos
    func obtenerDatos(){
        print("Obteniendo")
        let prefs:UserDefaults = UserDefaults.standard
        var id_usuario=prefs.string(forKey: "IDUSUARIO")! as String
        var post:NSString = "id_usuario=\(id_usuario)&radio=\(kmSlider.value)" as NSString
        
        var ruta = Utils.agafaRuta(string: "usuarios_mapa.php")
        let url:NSURL = NSURL(string: ruta as String)!
        
        let postData:NSData = post.data(using: String.Encoding.ascii.rawValue)! as NSData
        
        let postLength:NSString = String( postData.length ) as NSString
        
        let request:NSMutableURLRequest = NSMutableURLRequest(url: (url as NSURL) as URL)
        request.httpMethod = "POST"
        request.httpBody = postData as Data
        request.setValue(postLength as String, forHTTPHeaderField: "Content-Length")
        request.setValue("application/x-www-form-urlencoded", forHTTPHeaderField: "Content-Type")
        request.setValue("application/json", forHTTPHeaderField: "Accept")
        
        
        var reponseError: NSError?
        var response: URLResponse?
        
        var urlData: NSData?
        do {
            urlData = try NSURLConnection.sendSynchronousRequest(request as URLRequest, returning:&response) as NSData?
        } catch var error as NSError {
            reponseError = error
            urlData = nil
        }
        
        if ( urlData != nil ) {
            let res = response as! HTTPURLResponse!;
            
            var responseData:NSString  = NSString(data:urlData! as Data, encoding:String.Encoding.utf8.rawValue)!
            
            if ((res?.statusCode)! >= 200 && (res?.statusCode)! < 300)
            {
                let json = JSON(data: urlData! as Data)
                
                total_usuarios = json.count
                if(json.count>0){
                    for index in 0...(json.count-1)
                    {
                        //guardamos la información descodificada en arrays
                        nombres.append((json[index]["nombre"].stringValue as NSString) as String)
                        idUsuarios.append((json[index]["id_usuario"].intValue as Int) as Int)
                        latitudes.append((json[index]["latitud"].stringValue as NSString) as String)
                        longitudes.append((json[index]["longitud"].stringValue as NSString) as String)
                    }
                    
                }
            }
            else
            {
                SCLAlertView().showError("Error", subTitle:"La connexión falló", closeButtonTitle:"Cerrar")
                
            }
        }
        else
        {
            SCLAlertView().showError("Error", subTitle:"La connexión falló2", closeButtonTitle:"Cerrar")
            
        }
    }
    
    
    //Mostramos el menú popup
    @IBAction func menuAction(_ sender: AnyObject) {
        let alert = SCLAlertView()
        alert.addButton("Actualizar posición", target:self, selector:Selector("actualizarPosicion"))
        alert.showInfo("", subTitle: "¿Actualizar la geolocalización de tus libros con tu posición actual?",closeButtonTitle:"No")
    }
    
    
    //Se envia al servidor la nueva localización del usuario y se guarda en la base de datos
    func actualizarPosicion()
    {
        let prefs:UserDefaults = UserDefaults.standard
        var id_usuario=prefs.string(forKey: "IDUSUARIO")! as String
        var post:NSString = "id_usuario=\(id_usuario)&lat=\(latitud_usuario)&lon=\(longitud_usuario)" as NSString
        
        var ruta = Utils.agafaRuta(string: "actualizar_posicion.php")
        let url:NSURL = NSURL(string: ruta as String)!
        
        let postData:NSData = post.data(using: String.Encoding.ascii.rawValue)! as NSData
        
        let postLength:NSString = String( postData.length ) as NSString
        
        let request:NSMutableURLRequest = NSMutableURLRequest(url: (url as NSURL) as URL)
        request.httpMethod = "POST"
        request.httpBody = postData as Data
        request.setValue(postLength as String, forHTTPHeaderField: "Content-Length")
        request.setValue("application/x-www-form-urlencoded", forHTTPHeaderField: "Content-Type")
        request.setValue("application/json", forHTTPHeaderField: "Accept")
        
        
        var reponseError: NSError?
        var response: URLResponse?
        
        var urlData: NSData?
        do {
            urlData = try NSURLConnection.sendSynchronousRequest(request as URLRequest, returning:&response) as NSData?
        } catch var error as NSError {
            reponseError = error
            urlData = nil
        }
        
        if ( urlData != nil ) {
            let res = response as! HTTPURLResponse!;
            
            var responseData:NSString  = NSString(data:urlData! as Data, encoding:String.Encoding.utf8.rawValue)!
            
            if ((res?.statusCode)! >= 200 && (res?.statusCode)! < 300)
            {
                let jsonData:NSDictionary = (try! JSONSerialization.jsonObject(with: urlData! as Data, options:JSONSerialization.ReadingOptions.mutableContainers )) as! NSDictionary
                
                let success:NSInteger = jsonData.value(forKey: "success") as! NSInteger
                
                if(success == 1)
                {
                    mapView.removeAnnotations(mapView.annotations)
                    latitudes.removeAll()
                    longitudes.removeAll()
                    nombres.removeAll()
                    idUsuarios.removeAll()
                    obtenerDatos()
                    completarMapa()
                }
                else
                {
                    var error_msg:NSString
                    
                    if jsonData["error_message"] as? NSString != nil
                    {
                        error_msg = jsonData["error_message"] as! NSString
                    }
                    else
                    {
                        error_msg = "Unknown Error"
                    }
                    SCLAlertView().showError("Error", subTitle:error_msg as String, closeButtonTitle:"Cerrar")
                }

            }
            else
            {
                SCLAlertView().showError("Error", subTitle:"La connexión falló", closeButtonTitle:"Cerrar")
                
            }
        }
        else
        {
            SCLAlertView().showError("Error", subTitle:"La connexión falló2", closeButtonTitle:"Cerrar")
            
        }
    }
    
    
    //Función que cambia de pantalla
    func pressed() {
        self.performSegue(withIdentifier: "goToCambio", sender: self)
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }
    
    
    //Función que se ejecuta al cargar la pantalla la primera vez
    override func viewDidLoad() {
        super.viewDidLoad()
        var selectedValue = Int(kmSlider.value)
        kmLabel.text = String(stringInterpolationSegment: selectedValue) + " KM"
        obtenerDatos()
        completarMapa()
    }
    
    
    //Cambiamos de pantalla con paso de parámetros
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "goToCambio" {
            let vc = segue.destination as! LIbrosOfrecidosController
            vc.id_usuario = id_usuario
            vc.nombre_usuario = nombre_usuario
        }
    }
    
    
}


