//
//  NuevoLibroController.swift
//  trotalibros
//
//  Created by Andorsoft on 15/11/16.
//  Copyright © 2016 EDU. All rights reserved.
//  Clase que crea un libro en la base de datos

import UIKit
import QuartzCore

class NuevoLibroController: UIViewController, UIPickerViewDataSource, UIPickerViewDelegate {
    
    //variables conectadas con los elementos de la pantalla
    @IBOutlet weak var tituloField:   UITextField!
    @IBOutlet weak var autorField: UITextField!
    @IBOutlet weak var pickerView: UIPickerView!
    
    //variables internas
    var titulo: NSString = ""
    var isbn: NSString = ""
    var idioma: NSString = ""
    var editorial: NSString = ""
    var sinopis: NSString = ""
    var autor: NSString = ""
    var id_libro: Int = 0
    var generos: [String] = []
    var id_generos: [Int] = []
    
    
    //Guardamos el libro en nuestra base de datos. Los datos se envian por POST
    @IBAction func AceptarLibro(_ sender: Any) {
        
        if(tituloField.text!.isEmpty || autorField.text!.isEmpty || isbn == nil || isbn == "" )
        {
            SCLAlertView().showWarning("ATENCIÓN", subTitle: "Todos los campos son obligatorios",closeButtonTitle:"OK")
        }
        else
        {
            let x = pickerView.selectedRow(inComponent: 0)
            let post:NSString = "titulo=\(tituloField.text!)&autor=\(autorField.text!)&id_genero=\(id_generos[x])&idioma=\(idioma)&editorial=\(editorial)&sinopis=\(sinopis)&isbn=\(isbn)" as NSString
            print (post)
            let ruta = Utils.agafaRuta(string: "crear_libro.php")
            let url:NSURL = NSURL(string: ruta as String)!
            
            let postData:NSData = post.data(using: String.Encoding.utf8.rawValue)! as NSData
            
            let postLength:NSString = String( postData.length ) as NSString
            
            let request:NSMutableURLRequest = NSMutableURLRequest(url: (url as NSURL) as URL)
            request.httpMethod = "POST"
            request.httpBody = postData as Data
            request.setValue(postLength as String, forHTTPHeaderField: "Content-Length")
            request.setValue("application/x-www-form-urlencoded", forHTTPHeaderField: "Content-Type")
            request.setValue("application/json", forHTTPHeaderField: "Accept")
            
            var reponseError: NSError?
            var response: URLResponse?
            
            var urlData: NSData?
            do
            {
                urlData = try NSURLConnection.sendSynchronousRequest(request as URLRequest, returning:&response) as NSData?
            }
            catch var error as NSError
            {
                reponseError = error
                urlData = nil
            }
            
            if ( urlData != nil )
            {
                let res = response as! HTTPURLResponse!;
            
                var responseData:NSString  = NSString(data:urlData! as Data, encoding:String.Encoding.utf8.rawValue)!
                
                if ((res?.statusCode)! >= 200 && (res?.statusCode)! < 300)
                {
                    var responseData:NSString  = NSString(data:urlData! as Data, encoding:String.Encoding.utf8.rawValue)!
                    
                    var error: NSError?
                    
                    let jsonData:NSDictionary = (try! JSONSerialization.jsonObject(with: urlData! as Data, options:JSONSerialization.ReadingOptions.mutableContainers )) as! NSDictionary
                    
                    let success:NSInteger = jsonData.value(forKey: "success") as! NSInteger
                    
                    //Si se ha guardado con éxito cambiamos de pantalla para subir la portada
                    if(success == 1)
                    {
                        id_libro = jsonData.value(forKey: "id_libro") as! NSInteger
                        self.performSegue(withIdentifier: "gotoToImagen", sender: self)
                    }
                    else
                    {
                        var error_msg:NSString
                        
                        if jsonData["error_message"] as? NSString != nil
                        {
                            error_msg = jsonData["error_message"] as! NSString
                        }
                        else
                        {
                            error_msg = "Unknown Error"
                        }
                        SCLAlertView().showError("Error", subTitle:error_msg as String, closeButtonTitle:"Cerrar")
                    }
                    
                }
                else
                {
                    SCLAlertView().showError("Error", subTitle:"La connexión falló", closeButtonTitle:"Cerrar")
                }
            }
            else
            {
                SCLAlertView().showError("Error", subTitle:"La connexión falló2", closeButtonTitle:"Cerrar")
            }

        }
        
    }
    
    //Obtenemos los géneros de la base de datos y los guardamos en un array
    func obtenerGeneros(){
        
        var ruta = Utils.agafaRuta(string: "coge_generos.php")
        let url:NSURL = NSURL(string: ruta as String)!
        let request:NSMutableURLRequest = NSMutableURLRequest(url: (url as NSURL) as URL)
        request.setValue("application/x-www-form-urlencoded", forHTTPHeaderField: "Content-Type")
        request.setValue("application/json", forHTTPHeaderField: "Accept")
        
        var reponseError: NSError?
        var response: URLResponse?
        
        var urlData: NSData?
        do {
            urlData = try NSURLConnection.sendSynchronousRequest(request as URLRequest, returning:&response) as NSData?
        } catch var error as NSError {
            reponseError = error
            urlData = nil
        }
        
        if ( urlData != nil ) {
            let res = response as! HTTPURLResponse!;
            
            var responseData:NSString  = NSString(data:urlData! as Data, encoding:String.Encoding.utf8.rawValue)!
            
            if ((res?.statusCode)! >= 200 && (res?.statusCode)! < 300)
            {
                let json = JSON(data: urlData! as Data)
                
                if(json.count>0){
                    for index in 0...(json.count-1)
                    {
                        //guardamos la información en arrays para rellenar el picker
                        generos.append((json[index]["genero"].stringValue as NSString) as String)
                        id_generos.append((json[index]["id_genero"].intValue) )
                    }
                }
            }
            else
            {
                SCLAlertView().showError("Error", subTitle:"La connexión falló", closeButtonTitle:"Cerrar")
                
            }
        }
        else
        {
            SCLAlertView().showError("Error", subTitle:"La connexión falló2", closeButtonTitle:"Cerrar")
            
        }
    }
    
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }
    
    //Función que se ejecuta al iniciar la pantalla la primera vez
    override func viewDidLoad() {
        super.viewDidLoad()
        obtenerGeneros()
        tituloField.text = titulo as String
        autorField.text = autor as String
        self.pickerView.dataSource = self;
        self.pickerView.delegate = self;
    }
    
    //Escodenmos el teclado 
    func textFieldShouldReturn(textField: UITextField) -> Bool {
        tituloField.resignFirstResponder()
        autorField.resignFirstResponder()
        return true;
    }
    
      //Escodenmos el teclado al tocar el fondo de pantalla
    override func touchesBegan(_ touches: Set<UITouch>, with event: UIEvent?) {
        tituloField.resignFirstResponder()
        autorField.resignFirstResponder()
        self.view.endEditing(true)
    }
    
    func numberOfComponents(in pickerView: UIPickerView) -> Int {
        return 1
    }
    
    func pickerView(_ pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int {
        return generos.count;
    }
    
    //rellenamos el picker con los generos guardados en el array
    func pickerView(_ pickerView: UIPickerView, titleForRow row: Int, forComponent component: Int) -> String? {
        return generos[row]
    }
    
    func pickerView(_ pickerView: UIPickerView, didSelectRow row: Int, inComponent component: Int)
    {
        print(row)
    }
    
    //Se preparan los parámetros para cambiar de pantalla
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "gotoToImagen" {
            let vc = segue.destination as! SubirImagenController
            vc.id_libro=id_libro
        }
    }

}





