//
//  PermutasController.swift
//  trotalibros
//
//  Created by EDU on 30/11/16.
//  Copyright © 2016 EDU. All rights reserved.
//  Clase que muestra un formato tabla las permutas del usuario

import Foundation
import UIKit
import QuartzCore

class PermutasController: UITableViewController {
    
    //variables internas
    var titulosEmisor: [String] = []
    var titulosReceptor: [String] = []
    var tipos: [Int] = []
    var comentariosEmisor: [String] = []
    var idUsuariosReceptor: [Int] = []
    var idUsuariosEmisor: [Int] = []
    var idPermutas: [Int] = []
    var estados: [Int] = []
    
    //Se obtiene las permutas del usuario y se guardan en una array
    func obtenerDatos(){
        let prefs:UserDefaults = UserDefaults.standard
        var id_usuario=prefs.string(forKey: "IDUSUARIO")! as String
        
        var post:NSString = "id_usuario=\(id_usuario)" as NSString
        
        var ruta = Utils.agafaRuta(string: "permutas.php")
        let url:NSURL = NSURL(string: ruta as String)!
        
        let postData:NSData = post.data(using: String.Encoding.utf8.rawValue)! as NSData
        
        let postLength:NSString = String( postData.length ) as NSString
        
        let request:NSMutableURLRequest = NSMutableURLRequest(url: (url as NSURL) as URL)
        request.httpMethod = "POST"
        request.httpBody = postData as Data
        request.setValue(postLength as String, forHTTPHeaderField: "Content-Length")
        request.setValue("application/x-www-form-urlencoded", forHTTPHeaderField: "Content-Type")
        request.setValue("application/json", forHTTPHeaderField: "Accept")        
        
        var reponseError: NSError?
        var response: URLResponse?
        
        var urlData: NSData?
        do {
            urlData = try NSURLConnection.sendSynchronousRequest(request as URLRequest, returning:&response) as NSData?
        } catch var error as NSError {
            reponseError = error
            urlData = nil
        }
        
        if ( urlData != nil ) {
            let res = response as! HTTPURLResponse!;
            
            var responseData:NSString  = NSString(data:urlData! as Data, encoding:String.Encoding.utf8.rawValue)!
            
            NSLog("Response ==> %@", responseData);
            
            if ((res?.statusCode)! >= 200 && (res?.statusCode)! < 300)
            {
                let json = JSON(data: urlData! as Data)
                if(json.count>0){
                    for index in 0...(json.count-1)
                    {
                        //guardamos cada permuta en arrays, cada una para un parámetro
                        titulosEmisor.append((json[index]["titulo_emisor"].stringValue as NSString) as String)
                        titulosReceptor.append((json[index]["titulo_receptor"].stringValue as NSString) as String)
                        tipos.append(json[index]["tipo"].intValue as Int)
                        comentariosEmisor.append((json[index]["comentario_emisor"].stringValue as NSString) as String)
                        idUsuariosReceptor.append(json[index]["id_usuario_receptor"].intValue as Int)
                        idUsuariosEmisor.append(json[index]["id_usuario_emisor"].intValue as Int)
                        idPermutas.append(json[index]["id_permuta"].intValue as Int)
                        estados.append(json[index]["estado"].intValue as Int)
                        
                    }
                }
                self.tableView!.reloadData()
                
            }
            else
            {
                SCLAlertView().showError("Error", subTitle:"La connexión falló", closeButtonTitle:"Cerrar")
                
            }
        }
        else
        {
            SCLAlertView().showError("Error", subTitle:"La connexión falló2", closeButtonTitle:"Cerrar")
            
        }
    }
    
    
    
    override func tableView(_ tableView: UITableView?, numberOfRowsInSection section: Int) -> Int
    {
        return self.titulosEmisor.count;
    }
    
    
    //Rellenamos cada fila de la tabla con una permuta. cada elemento de la fila tiene un TAG que lo diferencia
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "permutaCell", for: indexPath)
        
        if let estadoLabel = cell.viewWithTag(4) as? UILabel //Estado de la permuta
        {
            if(self.estados[indexPath.row]==0)
            {
                estadoLabel.text = ""
            }
            else
            {
                if(self.estados[indexPath.row]==1)
                {
                    estadoLabel.text = "Rechazada"
                     estadoLabel.textColor = UIColor.red
                }
                else
                {
                    if(self.estados[indexPath.row]==2)
                    {
                        estadoLabel.text = "Aceptada"
                        estadoLabel.textColor = UIColor.green
                    }
                }
            }
        }

        
        
        if let label = cell.viewWithTag(2) as? UILabel //Quien ha hecho la permuta
        {
            if(self.tipos[indexPath.row]==0)
            {
               label.text = "Pides"
            }
            else
            {
                label.text = "Te ofrecen"
            }
        }
        
        if let libroLabel = cell.viewWithTag(1) as? UILabel ////Quien ha hecho la permuta
        {
            if(self.tipos[indexPath.row]==0)
            {
                libroLabel.text = titulosReceptor[indexPath.row]
            }
            else
            {
                libroLabel.text = titulosEmisor[indexPath.row]
            }
        }
        
        if var imagen = cell.viewWithTag(3) as? UIImageView { //Quien ha hecho la permuta
            
            if(self.tipos[indexPath.row]==0)
            {
                imagen.contentMode = UIViewContentMode.scaleToFill
                imagen.image = UIImage(named: "out")!
                
            }
            else
            {
                imagen.contentMode = UIViewContentMode.scaleToFill
                imagen.image = UIImage(named: "in")!
                
            } 
        }
        
        return cell
    }
    
    
    //Ponemos un título a la tabla
    override func tableView(_ tableView: UITableView, titleForHeaderInSection section: Int) -> String?
    {
        return "Tienes \(self.titulosEmisor.count) permutas"
    }
    
    //Se prepara los parámetros para cambiar de pantalla
    override func prepare(for segue: UIStoryboardSegue, sender: Any?)
    {
        let index = tableView.indexPathForSelectedRow! //cogemos el índice de la fila selecionada
        
        if segue.identifier == "goToOfrezco" {
            let vc = segue.destination as! PermutaDetalleController
            vc.id_permuta = self.idPermutas[index.row]
        }
    }
    
    override func didReceiveMemoryWarning()
    {
        super.didReceiveMemoryWarning()
    }
    
    
    //Actualizamos cuando volvemos a la pantalla
    override func viewWillAppear(_ animated: Bool)
    {
        super.viewWillAppear(animated)
        actualizar()
    }
    
    //Actualizamos permutas y eliminamos todo lo anterior para no duplicar
    func actualizar()
    {
        self.tableView .reloadData()
        self.refreshControl?.endRefreshing()
        titulosEmisor.removeAll()
        titulosReceptor.removeAll()
        tipos.removeAll()
        comentariosEmisor.removeAll()
        idUsuariosReceptor.removeAll()
        idUsuariosEmisor.removeAll()
        idPermutas.removeAll()
        estados.removeAll()
        self.obtenerDatos();
    }
    
    //Función que se ejecuta al iniciar la pantalla la primera vez
    override func viewDidLoad()
    {
        super.viewDidLoad()
        self.title = "Permutas"
        obtenerDatos()
        var refreshControl = UIRefreshControl()
        refreshControl.addTarget(self, action: Selector("actualizar"), for: UIControlEvents.valueChanged)
        self.refreshControl = refreshControl
    }
    
}


