//
//  SubirImagenController.swift
//  trotalibros
//
//  Created by Andorsoft on 16/11/16.
//  Copyright © 2016 EDU. All rights reserved.
//  Clase que sube la imagen de portada de un libro

import Foundation
import UIKit
import QuartzCore

class SubirImagenController: UIViewController, UIImagePickerControllerDelegate, UINavigationControllerDelegate {
    
     //variables conectadas con los elementos de la pantalla
    @IBOutlet var image: UIImageView!
    @IBOutlet weak var omitirButton: UIButton!
    @IBOutlet weak var seleccionButton: UIButton!
    @IBOutlet weak var SubirButton: UIButton!
    @IBOutlet weak var activity: UIActivityIndicatorView!
    @IBOutlet weak var enviarButton: UIButton!
    //variables internas
    var id_libro = 0
    var respuesta: NSString = ""
    
    
    //cambiamos de pantalla al pulsar el botón
    @IBAction func omitirButton(_ sender: Any) {
         self.performSegue(withIdentifier: "goToLibro", sender: self)
    }
    
    //Seleccionamos una imagen guardada en el teléfono
    @IBAction func selectPicture(sender: AnyObject) {
        let ImagePicker = UIImagePickerController()
        ImagePicker.delegate = self
        ImagePicker.sourceType = UIImagePickerControllerSourceType.photoLibrary
        
        self.present(ImagePicker, animated: true, completion: nil)
    }
    
    //Mostramos la imagen selecionada
    func imagePickerController(_ picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [String : Any])
    {
        let selectedImage = info[UIImagePickerControllerOriginalImage] as! UIImage
        
        image.image = selectedImage
        SubirButton.isHidden = false
        dismiss(animated: true, completion: nil)
    }
    
    //Enviamos por POST la imagen y el resto de datos para guardar en la base de datos
    @IBAction func subirImagen(_ sender: AnyObject) {
        activity.isHidden = false
        activity.startAnimating()
        enviarButton.isHidden = true
        image.isHidden = true
        SubirButton.isHidden = true
        omitirButton.isHidden = true
        seleccionButton.isHidden = true
        let ruta = Utils.agafaRuta(string: "subir_portada.php")
        let url:NSURL = NSURL(string: ruta as String)!
        
        let request = NSMutableURLRequest(url: url as URL)
        request.httpMethod = "POST"
        
        let boundary = generateBoundaryString()
        
        request.setValue("multipart/form-data; boundary=\(boundary)", forHTTPHeaderField: "Content-Type")
        
        if (image.image == nil)
        {
            return
        }
        
        let image_data = UIImagePNGRepresentation(image.image!)
        
        
        if(image_data == nil)
        {
            return
        }
        
        let body = NSMutableData()
        
        let fname = "test.png"
        let mimetype = "image/png"
        
        //define the data post parameter
        
        body.append("--\(boundary)\r\n".data(using: String.Encoding.utf8)!)
        body.append("Content-Disposition:form-data; name=\"id_libro\"\r\n\r\n".data(using: String.Encoding.utf8)!)
        body.append("\(id_libro)\r\n".data(using: String.Encoding.utf8)!)
        body.append("--\(boundary)\r\n".data(using: String.Encoding.utf8)!)
        body.append("Content-Disposition:form-data; name=\"file\"; filename=\"\(fname)\"\r\n".data(using: String.Encoding.utf8)!)
        body.append("Content-Type: \(mimetype)\r\n\r\n".data(using: String.Encoding.utf8)!)
        body.append(image_data!)
        body.append("\r\n".data(using: String.Encoding.utf8)!)
        body.append("--\(boundary)--\r\n".data(using: String.Encoding.utf8)!)
        
        request.httpBody = body as Data
        
        let session = URLSession.shared
        
        let task = session.dataTask(with: request as URLRequest) {
            (
            data, response, error) in
            
            guard let _:NSData = data as NSData?, let _:URLResponse = response  , error == nil else {
                print("error")
                return
            }
            
            self.respuesta = NSString(data: data!, encoding: String.Encoding.utf8.rawValue)! as NSString

            DispatchQueue.main.async(execute: {
                self.activity.isHidden = true
                self.image.isHidden = false
                self.activity.stopAnimating()
                if(self.respuesta=="0"){
                    SCLAlertView().showError("Error", subTitle:"Datos inválidos.", closeButtonTitle:"Cerrar")
                    self.SubirButton.isHidden = false
                    self.enviarButton.isHidden = false
                    self.omitirButton.isHidden = false
                    self.seleccionButton.isHidden = false
                }
                else{
                    if(self.respuesta=="2"){
                        SCLAlertView().showError("Error", subTitle:"No se ha podidio subir la imagen.", closeButtonTitle:"Cerrar")
                        self.SubirButton.isHidden = false
                        self.enviarButton.isHidden = false
                        self.omitirButton.isHidden = false
                         self.seleccionButton.isHidden = false
                    }
                    else{
                        if(self.respuesta=="3"){
                            SCLAlertView().showError("Error", subTitle:"Archivo no permitido o excede el tamaño.", closeButtonTitle:"Cerrar")
                            self.SubirButton.isHidden = false
                            self.enviarButton.isHidden = false
                            self.omitirButton.isHidden = false
                             self.seleccionButton.isHidden = false
                        }
                        else{ //Si se ha subido correctamente cambiamos de pantalla
                            self.performSegue(withIdentifier: "goToLibro", sender: self)
                        }
                    }
                }
            })
        }
        
        task.resume()
    }
    
    
    func generateBoundaryString() -> String
    {
        return "Boundary-\(NSUUID().uuidString)"
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }

    override func viewDidLoad() {
        super.viewDidLoad()
        activity.isHidden = true

    }
    
    //Se preparan los parámetros para cambiar de pantalla
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "goToLibro" {
            let vc = segue.destination as! LibroController
            vc.id_libro=id_libro
        }
    }

    
}
