//
//  TrotarLibroController.swift
//  trotalibros
//
//  Created by Andorsoft on 30/11/16.
//  Copyright © 2016 EDU. All rights reserved.
//

import Foundation
import UIKit
import QuartzCore

class TrotarLibroController: UIViewController, UIImagePickerControllerDelegate, UINavigationControllerDelegate {
    
     //variables conectadas con los elementos de la pantalla
    @IBOutlet weak var descripcionText: UITextView!
    @IBOutlet weak var aceptarButton: UIButton!
    @IBOutlet weak var imagen: UIImageView!
    @IBOutlet weak var subirImagenButton: UIButton!
    @IBOutlet weak var activity: UIActivityIndicatorView!
    
    //variables internas
    var id_libro: Int = 0
    var respuesta: NSString = ""
    var subirImagen: Bool = true
    
    
    //Seleccionamos una imagen guardada en el teléfono
    @IBAction func subirImagen(_ sender: Any) {
        let ImagePicker = UIImagePickerController()
        ImagePicker.delegate = self
        ImagePicker.sourceType = UIImagePickerControllerSourceType.photoLibrary
        
        self.present(ImagePicker, animated: true, completion: nil)
    }
    
    
     //Enviamos por POST la imagen y el resto de datos para guardar en la base de datos
    @IBAction func aceptar(_ sender: Any) {
        activity.isHidden = false
        activity.startAnimating()
        aceptarButton.isHidden = true
        imagen.isHidden = true
        subirImagenButton.isHidden = true
        let prefs:UserDefaults = UserDefaults.standard
        var id_usuario=prefs.string(forKey: "IDUSUARIO")! as String
        let ruta = Utils.agafaRuta(string: "trotar_libro.php")
        let url:NSURL = NSURL(string: ruta as String)!
        
        let request = NSMutableURLRequest(url: url as URL)
        request.httpMethod = "POST"
        
        let boundary = generateBoundaryString()
        
        let body = NSMutableData()
        
        body.append("--\(boundary)\r\n".data(using: String.Encoding.utf8)!)
        body.append("Content-Disposition:form-data; name=\"descripcion\"\r\n\r\n".data(using: String.Encoding.utf8)!)
        body.append("\(descripcionText.text!)\r\n".data(using: String.Encoding.utf8)!)
        body.append("--\(boundary)\r\n".data(using: String.Encoding.utf8)!)
        body.append("Content-Disposition:form-data; name=\"id_libro\"\r\n\r\n".data(using: String.Encoding.utf8)!)
        body.append("\(id_libro)\r\n".data(using: String.Encoding.utf8)!)
        body.append("--\(boundary)\r\n".data(using: String.Encoding.utf8)!)
        body.append("Content-Disposition:form-data; name=\"id_usuario\"\r\n\r\n".data(using: String.Encoding.utf8)!)
        body.append("\(id_usuario)\r\n".data(using: String.Encoding.utf8)!)
        
        //define the multipart request type
        
        request.setValue("multipart/form-data; boundary=\(boundary)", forHTTPHeaderField: "Content-Type")
        
        if (imagen.image != nil)
        {
            let image_data = UIImagePNGRepresentation(imagen.image!)
            
            if(image_data != nil)
            {
                let fname = "test.png"
                let mimetype = "image/png"
                
                body.append("--\(boundary)\r\n".data(using: String.Encoding.utf8)!)
                body.append("Content-Disposition:form-data; name=\"file\"; filename=\"\(fname)\"\r\n".data(using: String.Encoding.utf8)!)
                body.append("Content-Type: \(mimetype)\r\n\r\n".data(using: String.Encoding.utf8)!)
                body.append(image_data!)
                body.append("\r\n".data(using: String.Encoding.utf8)!)
                body.append("--\(boundary)--\r\n".data(using: String.Encoding.utf8)!)

            }
        }
        
        request.httpBody = body as Data
        
        let session = URLSession.shared
        
        let task = session.dataTask(with: request as URLRequest) {
            (
            data, response, error) in
            
            guard let _:NSData = data as NSData?, let _:URLResponse = response  , error == nil else {
                print("error")
                return
            }
            
            self.respuesta = NSString(data: data!, encoding: String.Encoding.utf8.rawValue)! as NSString
            DispatchQueue.main.async(execute: {
                self.activity.isHidden = true
                self.imagen.isHidden = false
                self.activity.stopAnimating()
                
                if(self.respuesta=="0"){
                    SCLAlertView().showError("Error", subTitle:"Datos inválidos.", closeButtonTitle:"Cerrar")
                    self.subirImagenButton.isHidden = false
                }
                else{
                    if(self.respuesta=="1"){
                        SCLAlertView().showError("Error", subTitle:"No se ha podidio subir la imagen.", closeButtonTitle:"Cerrar")
                        self.subirImagenButton.isHidden = false
                    }
                    else{
                        if(self.respuesta=="2"){
                            SCLAlertView().showError("Error", subTitle:"Archivo no permitido o excede el tamaño.", closeButtonTitle:"Cerrar")
                            self.subirImagenButton.isHidden = false
                        }
                        else{
                            if(self.respuesta=="4"){
                                 SCLAlertView().showSuccess("", subTitle:"'Has dejado de trotar el libro!", closeButtonTitle:"Cerrar")
                                self.subirImagenButton.isHidden = false
                            }
                            else{
                                SCLAlertView().showSuccess("", subTitle:"¡Tu libro está listo para ser cambiado!", closeButtonTitle:"Cerrar")
                                self.aceptarButton.isHidden = true
                              
                            }
                        }
                    }
                }
            })
        }
        
        task.resume()
    }
    
    func generateBoundaryString() -> String
    {
        return "Boundary-\(NSUUID().uuidString)"
    }
    
    //Mostramos la imagen selecionada
    func imagePickerController(_ picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [String : Any])
    {
        let selectedImage = info[UIImagePickerControllerOriginalImage] as! UIImage        
        imagen.image = selectedImage
        dismiss(animated: true, completion: nil)
    }
    
    //Escondemos el teclado
    func textFieldShouldReturn(textField: UITextField) -> Bool {
        descripcionText.resignFirstResponder()
        return true;
    }
    
    //Escodenmos el teclado al tocar el fondo de pantalla
    override func touchesBegan(_ touches: Set<UITouch>, with event: UIEvent?) {
        descripcionText.resignFirstResponder()
        self.view.endEditing(true)
    }
    
    override func viewDidLoad()
    {
        activity.isHidden = true
        super.viewDidLoad()
    }

    
}
